@@ -27,9 +27,15 @@ import six
 from vdsm.network import cmd
 from vdsm.network.ip import dhclient
 from vdsm.network.netinfo.addresses import (
-    getIpAddrs, getIpInfo, is_ipv6_local_auto)
-from vdsm.network.netinfo.routes import (get_routes, get_gateway,
-                                         is_default_route)
+    getIpAddrs,
+    getIpInfo,
+    is_ipv6_local_auto,
+)
+from vdsm.network.netinfo.routes import (
+    get_routes,
+    get_gateway,
+    is_default_route,
+)
 from vdsm.network.link.iface import iface as iflink
 from . import driver
 
@@ -50,12 +56,22 @@ EMPTY_PORT_INFO = {
     'ipv6addrs': [],
     'ipv6autoconf': False,
     'ipv6gateway': '',
-    'dhcpv6': False
+    'dhcpv6': False,
 }
 
 SHARED_NETWORK_ATTRIBUTES = [
-    'mtu', 'addr', 'ipv4addrs', 'gateway', 'ipv4defaultroute', 'netmask',
-    'dhcpv4', 'ipv6addrs', 'ipv6autoconf', 'ipv6gateway', 'dhcpv6']
+    'mtu',
+    'addr',
+    'ipv4addrs',
+    'gateway',
+    'ipv4defaultroute',
+    'netmask',
+    'dhcpv4',
+    'ipv6addrs',
+    'ipv6autoconf',
+    'ipv6gateway',
+    'dhcpv6',
+]
 
 
 def is_ovs_service_running():
@@ -91,11 +107,16 @@ class OvsInfo(object):
         ovs_db = OvsDB(driver.create())
         self._ports_uuids = {port['_uuid']: port for port in ovs_db.ports}
         self._ifaces_uuids = {iface['_uuid']: iface for iface in ovs_db.ifaces}
-        self._ifaces_macs = {iface['mac_in_use']: iface
-                             for iface in ovs_db.ifaces if iface['mac_in_use']}
+        self._ifaces_macs = {
+            iface['mac_in_use']: iface
+            for iface in ovs_db.ifaces
+            if iface['mac_in_use']
+        }
 
-        self._bridges = {bridge['name']: self._bridge_attr(bridge)
-                         for bridge in ovs_db.bridges}
+        self._bridges = {
+            bridge['name']: self._bridge_attr(bridge)
+            for bridge in ovs_db.bridges
+        }
         self._bridges_by_sb = self._get_bridges_by_sb()
         self._northbounds_by_sb = self._get_northbounds_by_sb()
         self._northbounds_by_bridges = self._get_northbounds_by_bridges()
@@ -135,8 +156,7 @@ class OvsInfo(object):
     def _bridge_attr(self, bridge_entry):
         stp = bridge_entry['stp_enable']
         ports = [self._ports_uuids[uuid] for uuid in bridge_entry['ports']]
-        ports_info = {port['name']: self._port_attr(port)
-                      for port in ports}
+        ports_info = {port['name']: self._port_attr(port) for port in ports}
         dpdk_enabled = bridge_entry['datapath_type'] == 'netdev'
 
         return {'ports': ports_info, 'stp': stp, 'dpdk_enabled': dpdk_enabled}
@@ -152,18 +172,29 @@ class OvsInfo(object):
         return self._northbounds_by_bridges
 
     def _get_northbounds_by_bridges(self):
-        return {self.bridges_by_sb[sb]: nbs
-                for sb, nbs in six.iteritems(self.northbounds_by_sb)}
+        return {
+            self.bridges_by_sb[sb]: nbs
+            for sb, nbs in six.iteritems(self.northbounds_by_sb)
+        }
 
     @staticmethod
     def southbound_port(ports):
-        return next((port for port, attrs in six.iteritems(ports)
-                     if attrs['level'] == SOUTHBOUND), None)
+        return next(
+            (
+                port
+                for port, attrs in six.iteritems(ports)
+                if attrs['level'] == SOUTHBOUND
+            ),
+            None,
+        )
 
     @staticmethod
     def northbound_ports(ports):
-        return (port for port, attrs in six.iteritems(ports)
-                if attrs['level'] == NORTHBOUND)
+        return (
+            port
+            for port, attrs in six.iteritems(ports)
+            if attrs['level'] == NORTHBOUND
+        )
 
 
 def get_netinfo():
@@ -209,21 +240,14 @@ def _fake_devices(networks):
 
 
 def _fake_bridge(net_attrs):
-    bridge_info = {
-        'ports': net_attrs['ports'],
-        'stp': net_attrs['stp']
-    }
+    bridge_info = {'ports': net_attrs['ports'], 'stp': net_attrs['stp']}
     bridge_info.update(_shared_net_attrs(net_attrs))
     return bridge_info
 
 
 def _fake_vlan(net_attrs, vlanid):
     iface = net_attrs['southbound']
-    vlan_info = {
-        'vlanid': vlanid,
-        'iface': iface,
-        'mtu': net_attrs['mtu']
-    }
+    vlan_info = {'vlanid': vlanid, 'iface': iface, 'mtu': net_attrs['mtu']}
     vlan_info.update(EMPTY_PORT_INFO)
     vlan_name = '%s.%s' % (iface, vlanid)
     return {vlan_name: vlan_info}
@@ -244,14 +268,21 @@ def create_netinfo(ovs_info):
         stp = bridge_attrs['stp']
         for northbound_port in ovs_info.northbound_ports(ports):
             _netinfo['networks'][northbound_port] = _get_network_info(
-                northbound_port, bridge, southbound, ports, stp, addresses,
-                routes)
+                northbound_port,
+                bridge,
+                southbound,
+                ports,
+                stp,
+                addresses,
+                routes,
+            )
 
     return _netinfo
 
 
-def _get_network_info(northbound, bridge, southbound, ports, stp, addresses,
-                      routes):
+def _get_network_info(
+    northbound, bridge, southbound, ports, stp, addresses, routes
+):
     tag = ports[northbound]['tag']
     network_info = {
         'iface': northbound,
@@ -259,7 +290,7 @@ def _get_network_info(northbound, bridge, southbound, ports, stp, addresses,
         'southbound': southbound,
         'ports': _get_net_ports(bridge, northbound, southbound, tag, ports),
         'stp': stp,
-        'switch': 'ovs'
+        'switch': 'ovs',
     }
     if tag is not None:
         # TODO: We should always report vlan, even if it is None. Netinfo
@@ -277,9 +308,15 @@ def _get_net_ports(bridge, northbound, southbound, net_tag, ports):
         net_southbound_port = southbound
 
     net_ports = [net_southbound_port]
-    net_ports += [port for port, port_attrs in six.iteritems(ports)
-                  if (port_attrs['tag'] == net_tag and port != bridge and
-                      port_attrs['level'] not in (SOUTHBOUND, NORTHBOUND))]
+    net_ports += [
+        port
+        for port, port_attrs in six.iteritems(ports)
+        if (
+            port_attrs['tag'] == net_tag
+            and port != bridge
+            and port_attrs['level'] not in (SOUTHBOUND, NORTHBOUND)
+        )
+    ]
 
     return net_ports
 
@@ -287,16 +324,24 @@ def _get_net_ports(bridge, northbound, southbound, net_tag, ports):
 def _get_iface_info(iface, addresses, routes):
     ipv4gateway = get_gateway(routes, iface, family=4)
     ipv4addr, ipv4netmask, ipv4addrs, ipv6addrs = getIpInfo(
-        iface, addresses, ipv4gateway)
+        iface, addresses, ipv4gateway
+    )
     is_dhcpv4 = dhclient.is_active(iface, family=4)
     is_dhcpv6 = dhclient.is_active(iface, family=6)
     mtu = iflink(iface).mtu()
-    return {'mtu': mtu, 'addr': ipv4addr, 'ipv4addrs': ipv4addrs,
-            'gateway': ipv4gateway, 'netmask': ipv4netmask,
-            'ipv4defaultroute': is_default_route(ipv4gateway, routes),
-            'dhcpv4': is_dhcpv4, 'ipv6addrs': ipv6addrs,
-            'ipv6gateway': get_gateway(routes, iface, family=6),
-            'ipv6autoconf': is_ipv6_local_auto(iface), 'dhcpv6': is_dhcpv6}
+    return {
+        'mtu': mtu,
+        'addr': ipv4addr,
+        'ipv4addrs': ipv4addrs,
+        'gateway': ipv4gateway,
+        'netmask': ipv4netmask,
+        'ipv4defaultroute': is_default_route(ipv4gateway, routes),
+        'dhcpv4': is_dhcpv4,
+        'ipv6addrs': ipv6addrs,
+        'ipv6gateway': get_gateway(routes, iface, family=6),
+        'ipv6autoconf': is_ipv6_local_auto(iface),
+        'dhcpv6': is_dhcpv6,
+    }
 
 
 def fake_bridgeless(ovs_netinfo, kernel_netinfo, running_bridgeless_networks):
@@ -312,8 +357,9 @@ def fake_bridgeless(ovs_netinfo, kernel_netinfo, running_bridgeless_networks):
 
     for net in running_bridgeless_networks:
         net_attrs = ovs_netinfo['networks'][net]
-        iface_type, iface_name = _bridgeless_fake_iface(net_attrs,
-                                                        bonds_netinfo)
+        iface_type, iface_name = _bridgeless_fake_iface(
+            net_attrs, bonds_netinfo
+        )
 
         # NICs and BONDs are kernel devices, VLANs are OVS devices.
         if iface_type == 'nics':
